@@ -1,7 +1,7 @@
 package phpBB2::Simple;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -306,7 +306,7 @@ phpBB2::Simple - API for phpBB2
 
 =head1 VERSION
 
-This document describes version 0.02 of phpBB2::Simple (from Perl distribution phpBB2-Simple), released on 2015-08-18.
+This document describes version 0.03 of phpBB2::Simple (from Perl distribution phpBB2-Simple), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -321,7 +321,7 @@ web-based administration panel.
 
 =head2 add_user_to_groups(%args) -> [status, msg, result, meta]
 
-{en_US Add a user to one or more groups}.
+Add a user to one or more groups.
 
 Arguments ('*' denotes required arguments):
 
@@ -353,7 +353,7 @@ Return value:  (any)
 
 =head2 delete_user_from_all_forum_moderators(%args) -> [status, msg, result, meta]
 
-{en_US Delete a user from being moderator in all forums}.
+Delete a user from being moderator in all forums.
 
 Arguments ('*' denotes required arguments):
 
@@ -383,7 +383,7 @@ Return value:  (any)
 
 =head2 delete_user_from_groups(%args) -> [status, msg, result, meta]
 
-{en_US Delete a user from one or more groups}.
+Delete a user from one or more groups.
 
 Arguments ('*' denotes required arguments):
 
@@ -455,7 +455,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<detail> => I<bool>
 
-{en_US Returned detailed record for each item instead of just ID}.
+Returned detailed record for each item instead of just ID.
 
 =back
 
@@ -473,7 +473,7 @@ Return value:  (any)
 
 =head2 list_user_groups(%args) -> [status, msg, result, meta]
 
-{en_US List groups which user belongs to}.
+List groups which user belongs to.
 
 Arguments ('*' denotes required arguments):
 
@@ -509,7 +509,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<active> => I<bool>
 
-{en_US Only list active users}.
+Only list active users.
 
 =item * B<db_dsn>* => I<str>
 
@@ -519,11 +519,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<detail> => I<bool>
 
-{en_US Returned detailed record for each item instead of just ID}.
+Returned detailed record for each item instead of just ID.
 
 =item * B<level> => I<str>
 
-{en_US Only list users having certain level}.
+Only list users having certain level.
 
 =back
 
